﻿using System;
using System.Drawing;
using System.Windows.Forms;
using System.IO;

namespace FormPicboxAndWpfImgTest
{
	public partial class FmMain : Form
	{
		public FmMain()
		{
			InitializeComponent();
			this.Text = Application.ProductName;
			wpfImage.CreateImageControl();
		}

		//ドラッグ＆ドロップ
		private void FmMain_DragEnter(object sender, DragEventArgs e)
		{
			this.Activate();
			if (e.Data.GetDataPresent(DataFormats.FileDrop))
				e.Effect = System.Windows.Forms.DragDropEffects.Copy;
			else
				e.Effect = System.Windows.Forms.DragDropEffects.None;
		}
		//
		private void FmMain_DragDrop(object sender, DragEventArgs e)
		{
			string[] filePaths = (string[])e.Data.GetData(DataFormats.FileDrop);
			if (!Directory.Exists(filePaths[0])) return;

			filePaths = Directory.GetFiles(filePaths[0]);
			ShowImageFile(filePaths);
		}

		//画像ファイルを描画する
		private void ShowImageFile(string[] filePaths)
		{
			if (filePaths == null || filePaths.Length == 0) return;
			int count;

			SwStart();
			count = SetImages(filePaths, SetImagePictureBox);
			SwStop(lblFormTime, count);

			SwStart();
			count = SetImages(filePaths, SetImageWpfImage);
			SwStop(lblWpfTime, count);
		}

		private delegate void DlgtSetImage(Stream stream);
		private int SetImages(string[] filePaths, DlgtSetImage dlgtSetImage)
		{
			int count = 0;
			foreach (string filePath in filePaths)
			{
				if (string.IsNullOrEmpty(filePath)) continue;
				if (!filePath.ToLower().EndsWith(".jpg")) continue;
				Application.DoEvents();
				
				count++;
				using (FileStream fs = File.OpenRead(filePath))
				{
					dlgtSetImage(fs);
				}
			}
			return count;
		}
		
		private void SetImagePictureBox(Stream stream)
		{
			if (picBox.Image != null) picBox.Image.Dispose();
			picBox.Image = new Bitmap(stream);
		}
		
		private void SetImageWpfImage(Stream stream)
		{
			wpfImage.SetBitmapImage(stream);
		}

		//ストップウォッチ
		private DateTime dtStartTime;
		private void SwStart() { dtStartTime = DateTime.Now; }
		private void SwStop(Label lbl, int count)
		{
			lbl.Text = string.Format("{0}ms/{1}file", (DateTime.Now - dtStartTime).TotalMilliseconds, count);
		}

	}	//class
}	//namespace
